==> dokuwiki-2012.10.13.tgz: dokuwiki/lib/plugins/plugin/lang/nl/lang.php <==
<?php
/**
 * Dutch language file
 *
 * @author Wouter Schoot <wouter@schoot.org>
 * @author John de Graaff <john@de-graaff.net>
 * @author Niels Schoot <niels.schoot@quintiq.com>
 * @author Dion Nicolaas <dion@nicolaas.net>
 * @author Danny Rotsaert <danny.rotsaert@edpnet.be>
 * @author Marijn Hofstra hofstra.m@gmail.com
 * @author Matthias Carchon webmaster@c-mattic.be
 * @author Marijn Hofstra <hofstra.m@gmail.com>
 * @author Timon Van Overveldt <timonvo@gmail.com>
 * @author Jeroen
 * @author Ricardo Guijt <ricardoguijt@gmail.com>
 * @author Gerrit <klapinklapin@gmail.com>
 */
$lang['menu']                  = 'Plugins beheren';
$lang['download']              = 'Download en installeer een nieuwe plugin';
$lang['manage']                = 'Geïnstalleerde plugins';
$lang['btn_info']              = 'informatie';
$lang['btn_update']            = 'bijwerken';
$lang['btn_delete']            = 'verwijderen';
$lang['btn_settings']          = 'instellingen';
$lang['btn_download']          = 'Download';
$lang['btn_enable']            = 'Opslaan';
$lang['url']                   = 'URL';
$lang['installed']             = 'Geïnstalleerd:';
$lang['lastupdate']            = 'Laatst bijgewerkt:';
$lang['source']                = 'Bron:';
$lang['unknown']               = 'onbekend';
$lang['updating']              = 'Bijwerken ...';
$lang['updated']               = 'Plugin %s succesvol bijgewerkt';
$lang['updates']               = 'De volgende plugins zijn succesvol bijgewerkt';
$lang['update_none']           = 'Geen updates gevonden.';
$lang['deleting']              = 'Verwijderen ...';
$lang['deleted']               = 'Plugin %s verwijderd.';
$lang['downloading']           = 'Downloaden ...';
$lang['downloaded']            = 'Plugin %s succesvol geïnstalleerd';
$lang['downloads']             = 'De volgende plugins zijn succesvol geïnstalleerd:';
$lang['download_none']         = 'Geen plugins gevonden, of er is een onbekende fout opgetreden tijdens het downloaden en installeren.';
$lang['plugin']                = 'Plugin:';
$lang['components']            = 'Onderdelen';
$lang['noinfo']                = 'Deze plugin gaf geen informatie terug, misschien is hij defect.';
$lang['name']                  = 'Naam:';
$lang['date']                  = 'Datum:';
$lang['type']                  = 'Type:';
$lang['desc']                  = 'Omschrijving:';
$lang['author']                = 'Auteur:';
$lang['www']                   = 'Weblocatie:';
$lang['error']                 = 'Er is een onbekende fout opgetreden.';
$lang['error_download']        = 'Kan het volgende plugin bestand niet downloaden: %s';
$lang['error_badurl']          = 'Vermoedelijk onjuiste url - kan de filename niet uit de url afleiden';
$lang['error_dircreate']       = 'Kan geen tijdelijke directory aanmaken voor de download';
$lang['error_decompress']      = 'De pluginmanager kan het gedownloade bestand niet uitpakken. Dit kan het resultaat zijn van een mislukte download: probeer het opnieuw; of het compressieformaat is onbekend: in dat geval moet je de plugin handmatig downloaden en installeren.';
$lang['error_copy']            = 'Er was een probleem met het kopiëren van een bestand tijdens de installatie van plugin <em>%s</em>: de schijf kan vol zijn of onjuiste toegangsrechten hebben. Dit kan tot gevolg hebben dat de plugin slechts gedeeltelijk geïnstalleerd is en kan uw wiki onstabiel maken.';
$lang['error_delete']          = 'Er is een probleem opgetreden tijdens het verwijderen van plugin <em>%s</em>. De meest voorkomende oorzaak is onjuiste toegangsrechten op bestanden of directory\'s.';
$lang['enabled']               = 'Plugin %s ingeschakeld.';
$lang['notenabled']            = 'Plugin %s kon niet worden ingeschakeld, controleer bestandsrechten.';
$lang['disabled']              = 'Plugin %s uitgeschakeld.';
$lang['notdisabled']           = 'Plugin %s kon niet worden uitgeschakeld, controleer bestandsrechten.';
$lang['packageinstalled']      = 'Plugin package (%d plugin(s): %s) succesvol geïnstalleerd.';

==> dokuwiki-2013.12.08.tgz: dokuwiki/lib/plugins/plugin/lang/nl/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Wouter Schoot <wouter@schoot.org>
 * @author John de Graaff <john@de-graaff.net>
 * @author Niels Schoot <niels.schoot@quintiq.com>
 * @author Dion Nicolaas <dion@nicolaas.net>
 * @author Danny Rotsaert <danny.rotsaert@edpnet.be>
 * @author Marijn Hofstra hofstra.m@gmail.com
 * @author Matthias Carchon webmaster@c-mattic.be
 * @author Marijn Hofstra <hofstra.m@gmail.com>
 * @author Timon Van Overveldt <timonvo@gmail.com>
 * @author Jeroen
 * @author Ricardo Guijt <ricardoguijt@gmail.com>
 * @author Gerrit <klapinklapin@gmail.com>
 * @author Remon <no@email.local>
 */
$lang['menu']                  = 'Plugins beheren';
$lang['download']              = 'Download en installeer een nieuwe plugin';
$lang['manage']                = 'Geïnstalleerde plugins';
$lang['btn_info']              = 'informatie';
$lang['btn_update']            = 'bijwerken';
$lang['btn_delete']            = 'verwijderen';
$lang['btn_settings']          = 'instellingen';
$lang['btn_download']          = 'Download';
$lang['btn_enable']            = 'Opslaan';
$lang['url']                   = 'URL';
$lang['installed']             = 'Geïnstalleerd:';
$lang['lastupdate']            = 'Laatst bijgewerkt:';
$lang['source']                = 'Bron:';
$lang['unknown']               = 'onbekend';
$lang['updating']              = 'Bijwerken ...';
$lang['updated']               = 'Plugin %s succesvol bijgewerkt';
$lang['updates']               = 'De volgende plugins zijn succesvol bijgewerkt';
$lang['update_none']           = 'Geen updates gevonden.';
$lang['deleting']              = 'Verwijderen ...';
$lang['deleted']               = 'Plugin %s verwijderd.';
$lang['downloading']           = 'Bezig met downloaden ...';
$lang['downloaded']            = 'Plugin %s succesvol geïnstalleerd';
$lang['downloads']             = 'De volgende plugins zijn succesvol geïnstalleerd:';
$lang['download_none']         = 'Geen plugins gevonden, of er is een onbekende fout opgetreden tijdens het downloaden en installeren.';
$lang['plugin']                = 'Plugin:';
$lang['components']            = 'Onderdelen';
$lang['noinfo']                = 'Deze plugin gaf geen informatie terug, misschien is hij defect.';
$lang['name']                  = 'Naam:';
$lang['date']                  = 'Datum:';
$lang['type']                  = 'Type:';
$lang['desc']                  = 'Omschrijving:';
$lang['author']                = 'Auteur:';
$lang['www']                   = 'Weblocatie:';
$lang['error']                 = 'Er is een onbekende fout opgetreden.';
$lang['error_download']        = 'Kan het volgende plugin bestand niet downloaden: %s';
$lang['error_badurl']          = 'Vermoedelijk onjuiste url - kan de bestandsnaam niet uit de url afleiden';
$lang['error_dircreate']       = 'Kan geen tijdelijke directory aanmaken voor de download';
$lang['error_decompress']      = 'De pluginmanager kan het gedownloade bestand niet uitpakken. Dit kan het resultaat zijn van een mislukte download: probeer het opnieuw; of het compressieformaat is onbekend: in dat geval moet je de plugin handmatig downloaden en installeren.';
$lang['error_copy']            = 'Er was een probleem met het kopiëren van een bestand tijdens de installatie van plugin <em>%s</em>: de schijf kan vol zijn of onjuiste toegangsrechten hebben. Dit kan tot gevolg hebben dat de plugin slechts gedeeltelijk geïnstalleerd is en kan de wiki onstabiel maken.';
$lang['error_delete']          = 'Er is een probleem opgetreden tijdens het verwijderen van plugin <em>%s</em>. De meest voorkomende oorzaak is onjuiste toegangsrechten op bestanden of directory\'s.';
$lang['enabled']               = 'Plugin %s ingeschakeld.';
$lang['notenabled']            = 'Plugin %s kon niet worden ingeschakeld, controleer bestandsrechten.';
$lang['disabled']              = 'Plugin %s uitgeschakeld.';
$lang['notdisabled']           = 'Plugin %s kon niet worden uitgeschakeld, controleer bestandsrechten.';
$lang['packageinstalled']      = 'Plugin package (%d plugin(s): %s) succesvol geïnstalleerd.';
